@@ -141,15 +141,15 @@ class ServiceManager(object):
     def load_service(self, api_name, api_version=None, permission_scope=None, force_refresh=False):
         """ Loads the requested service. If the service has already been loaded for this ServiceManager, return the previously loaded service (unless force_refresh is on). If it has not, delegate to get_credentials() as necessary.
         Args:
-            api_name (str): The Google API name (i.e., 'drive.googleapis.com') or a shorthand version of it (e.g., 'drive'). 
-            api_version (str, optional): The version of the API to use. If not provided, it will first check the DEFAULT_SCOPES mapping to determine if there is a default API. If not, it will attempt to use the directory service to determine the default API.  
+            api_name (str): The Google API name (i.e., 'drive.googleapis.com') or a shorthand version of it (e.g., 'drive').
+            api_version (str, optional): The version of the API to use. If not provided, it will first check the DEFAULT_SCOPES mapping to determine if there is a default API. If not, it will attempt to use the directory service to determine the default API.
             permission_scope (str): The permission scope that accompanies this service. If the service_key is listed in the DEFAULT_SCOPES, this is optional and the default will be pulled. As fully-qualified permission scopes generally start with "https://www.googleapis.com/auth/", that part is optional and will be added if not present.
             force_refresh (bool): Reload the service even if it already has been loaded. Default is False.
         Returns:
             The loaded service.
         """
         #OLD and NEEDING TO DELETE: The fullly qualified service path, which also becomes the filename in the credential directory where the authorization token is stored. If not provided, this is generated from the service key ({service_key}.googleapis.com-python.json)
-            
+
         if api_name in DEFAULT_SCOPES:
             keydata = DEFAULT_SCOPES[api_name]
             api_name = keydata[0]
@@ -168,7 +168,7 @@ class ServiceManager(object):
         if service_key in self.loaded_services and not force_refresh:
             return(self.loaded_services[service_key])
 
-        # either service_key or service_path is required            
+        # either service_key or service_path is required
 
         if self.api_key:
             # api keys should be used only for personal application and development
@@ -210,7 +210,7 @@ class ServiceManager(object):
         if not re.match('https', permission_scope):
             permission_scope = 'https://www.googleapis.com/auth/' + permission_scope
 
-            
+
         # determine ifr the credentials have already been authorized and are active
         credential_path = os.path.join(self.credential_directory, local_credential_file)
         if os.path.exists(credential_path):
@@ -218,27 +218,25 @@ class ServiceManager(object):
         else:
             credentials = None
 
-        if not credentials or not credentials.valid :
-            
+        if credentials and credentials.valid and credentials.expired and credentials.refresh_token:
+            # creds exist and arre valid, but are expired - so just refresh
+            credentials.refresh(google.auth.transport.requests.Request())
+        else
             # no credientials, or they are invalid!
-            if credentials and credentials.expired and credentials.refresh_token:
-                # creds exist, but are expired
-                credentials.refresh(google.auth.transport.requests.Request())
-            else:
-                # -- get new credentials 
-                # identify the path to the credential's secret file.
-                secret_path = os.path.join(self.credential_directory, self.secret_file)
+            # -- get new credentials
+            # identify the path to the credential's secret file.
+            secret_path = os.path.join(self.credential_directory, self.secret_file)
 
-                # a very detailed error message.
-                if not os.path.exists(secret_path):
-                    raise FileNotFoundError(f"Could not find an OAuth secret file at {secret_path}, which is required for ServiceManager.get_credentials() to attempt to complete the authorization permission for scope {permission_scope} (the scope-level permission should be stored in {local_credential_file}, but it does not exist or is no longer valid and needs to be authenticated). \n\nYou will need to indicate the correct path to your OAuth Credential JSON secret file or download a new copy from the Google Developers Console located at https://console.developers.google.com/apis/credentials/ before trying again.")
+            # a very detailed error message.
+            if not os.path.exists(secret_path):
+                raise FileNotFoundError(f"Could not find an OAuth secret file at {secret_path}, which is required for ServiceManager.get_credentials() to attempt to complete the authorization permission for scope {permission_scope} (the scope-level permission should be stored in {local_credential_file}, but it does not exist or is no longer valid and needs to be authenticated). \n\nYou will need to indicate the correct path to your OAuth Credential JSON secret file or download a new copy from the Google Developers Console located at https://console.developers.google.com/apis/credentials/ before trying again.")
 
-                # All set authorize flow.
-                flow = google_auth_oauthlib.flow.InstalledAppFlow.from_client_secrets_file(secret_path, permission_scope)
+            # All set authorize flow.
+            flow = google_auth_oauthlib.flow.InstalledAppFlow.from_client_secrets_file(secret_path, permission_scope)
                 credentials = flow.run_local_server(port=0)
-        
-            # Save the credentials for the next run
-            with open(credential_path, 'w') as token:
-                token.write(credentials.to_json())
-        
+
+        # Save the credentials for the next run
+        with open(credential_path, 'w') as token:
+            token.write(credentials.to_json())
+
         return(credentials)
